@@ -12,6 +12,7 @@ from drkns.context.clean_persistence_files import clean_persistence_files
 from drkns.context.sync import sync_in, sync_out
 from drkns.runner.run import run
 from drkns.runner.get_execution_plan import get_execution_plan
+from drkns.debug.get_debug_information import get_debug_information
 
 
 class Cli:
@@ -20,6 +21,7 @@ class Cli:
         self._args: Collection[str] = []
         self._command: str = None
         self._force_success: bool = False
+        self._summary: bool = False
 
     def handle(self):
         self._parse_args()
@@ -44,6 +46,10 @@ class Cli:
             self._clean()
             return
 
+        if self._command == 'debug':
+            self._debug()
+            return
+
         message = 'Unkown command: ' + self._command +\
                   '. Allowed commands are "run" and "check".'
         raise UnknownCommandException(message)
@@ -61,6 +67,12 @@ class Cli:
             provided_args.pop(index)
             self._force_success = True
 
+        summary_flag = '--summary'
+        if summary_flag in provided_args:
+            index = provided_args.index(summary_flag)
+            provided_args.pop(index)
+            self._summary = True
+
         for arg in provided_args:
             if arg.find('--') != -1:
                 message = 'Unkown command flag: ' + arg + \
@@ -122,7 +134,7 @@ class Cli:
         if len(self._args) > 0:
             target = self._args[0]
 
-        successful, output_lines = run(config_unit, target)
+        successful, output_lines = run(config_unit, target, self._summary)
         if len(output_lines) > 0:
             print('\n'.join(output_lines))
         if successful or self._force_success:
@@ -130,11 +142,16 @@ class Cli:
 
         sys.exit(1)
 
-    @staticmethod
-    def _clean():
+    # noinspection PyMethodMayBeStatic
+    def _clean(self):
         clean_persistence_files()
         sys.exit()
 
-    @staticmethod
-    def _get_config_unit() -> ConfigUnit:
+    def _debug(self):
+        config_unit = self._get_config_unit()
+        print(get_debug_information(config_unit))
+        sys.exit()
+
+    # noinspection PyMethodMayBeStatic
+    def _get_config_unit(self) -> ConfigUnit:
         return load('drkns.yml')
