@@ -1,4 +1,5 @@
 from typing import Tuple
+from subprocess import Popen
 
 
 from drkns.context.get_unit_step_path import persistence_directory
@@ -7,10 +8,12 @@ from drkns.util import sh
 
 def sync_in(target_s3_path: str) -> Tuple[int, str]:
     command = 'aws s3 sync {} {}'.format(target_s3_path, persistence_directory)
-    return sh(command)
+    status, output, _ = sh(command)
+    return status, output
 
 
 def sync_out(target_s3_path: str) -> Tuple[int, str]:
-    command = 'aws s3 sync --delete {} {}'.format(persistence_directory, target_s3_path)
-    return sh(command)
-
+    command = 'aws s3 sync --delete {} {}'.format(
+        persistence_directory, target_s3_path)
+    status, output, _ = sh(command)
+    return status, output
